@@ -17,17 +17,22 @@
 #' @return Plot of stability data with prediction curves and prediction intervals.
 #'
 #' @examples
-#' #load antigenicity data
+#' #Load antigenicity data
 #' data(antigenicity)
 #'
-#' #run step1.down fit
+#' #Run step1.down fit
 #' fit1 <- step1_down(data = antigenicity, y = "conc", .time = "time",
 #'  C = "Celsius", max_time_pred = 3)
 #'
-#' #plot raw data with prediction curves and prediction intervals.
+#' #Plot raw data with prediction curves and prediction intervals.
 #' step1_plot_PI(step1_down_object = fit1, xlim = NULL, ylim = NULL,
 #'  xname = "Time (Years)", yname = "Concentration", ribbon = TRUE)
 #'
+#' #Plot raw data with prediction curves and confidence intervals.
+#' #Also limit x-axis to values between 0 and 1.5 and limit y-axis to values between 0 and 105.
+#' step1_plot_PI(step1_down_object = fit1, xlim = c(0,1.5), ylim = c(0,105),
+#'  xname = "Time (Years)", yname = "Concentration", ribbon = TRUE)
+#'
 #' @import ggplot2
 #'
 #' @export step1_plot_PI
@@ -63,8 +68,9 @@ step1_plot_PI <- function (step1_down_object, xname = NULL, yname = NULL,
 
   plot = ggplot() + geom_point(data=dat, mapping=aes(x= time, y = y, colour = Celsius, shape = validation))  +
     labs( x = xname, y = yname) +
-    {if(!is.null(xlim))scale_x_continuous(limits = xlim)} +
-    {if(!is.null(ylim))scale_y_continuous(limits = ylim)} +
+   {if(!is.null(ylim)& is.null(xlim))coord_cartesian(ylim = ylim)} +
+   {if(is.null(ylim)& !is.null(xlim))coord_cartesian(xlim = xlim)} +
+   {if(!is.null(xlim) & !is.null(ylim))coord_cartesian(xlim = xlim, ylim = ylim)} +
     mytheme  +
     geom_line(data=pred, mapping=aes(x= time, y = Response, colour = Celsius, linetype = "Prediction")) +
     geom_line(data=pred, mapping=aes(x= time, y = PI1, colour = Celsius, linetype = prediction_i)) +
